@@ -172,7 +172,8 @@ function(object, newdata,
     
     for (i in 1:q) {
         if(ncomp > 1) {
-            G[i, ] = apply(object$variates$X[Yprim[, i] == 1, ], 2, mean)
+
+            G[i, ] = apply(object$variates$X[Yprim[, i] == 1, , drop = FALSE], 2, mean)
         }
         else {
             G[i, ] = mean(object$variates$X[Yprim[, i] == 1, ])
