@@ -70,6 +70,8 @@ function(X,
     if (any(keepX > p)) 
             stop("each component of 'keepX' must be lower or equal than ", p, ".")
 
+    if (ncomp > min(ncol(X), nrow(X)))
+    stop("use smaller 'ncomp'", call. = FALSE)
 
     vect.varX=vector(length=ncomp)
     names(vect.varX) = c(1:ncomp)
@@ -172,7 +174,9 @@ function(X,
                    iter = vect.iter,
                    rotation = mat.v,
                    x = mat.u,
-                   names = list(X = X.names, indiv = ind.names)
+                   names = list(X = X.names, indiv = ind.names),
+                   loadings=list(mat.v),
+                   variates=list(mat.u)
               ))
 			  
     class(result) = c("spca", "prcomp", "pca")
